@@ -142,6 +142,12 @@ class ProjectPointsValueError(Exception):
     """
 
 
+class OffshoreWindInputError(Exception):
+    """
+    Error for bad offshore wind inputs
+    """
+
+
 class OutputWarning(Warning):
     """
     Warning for suspect output files or data
@@ -166,12 +172,6 @@ class OffshoreWindInputWarning(Warning):
     """
 
 
-class OrcaOutputWarning(Warning):
-    """
-    Warning for bad ORCA outputs.
-    """
-
-
 class ConfigWarning(Warning):
     """
     Warning for unclear or default configuration inputs
